Evaluate the effect of epsilon on NSI
eval_eps.RdEvaluate the effect of epsilon on NSI
Usage
eval_eps(
X0 = NULL,
Xs = NULL,
W = NULL,
eps = NULL,
G = NULL,
top = NULL,
eps.n = 4,
na = 2,
nb = 2
)Arguments
- X0
initial condition matrix
- Xs
network diffusion steady state; required if W not provided
- W
symmetrically normalized adjacency matrix W = D^-1 A D^-1, see normalize_adj_mat() function; required if Xs is not provided
- eps
optional vector with epsilon values
- G
igraph object
- top
top genes to consider
- eps.n
number of eps points for every order of magnitude
- na
number of orders of magnitudes above the one detected in X0 to set max eps
- nb
number of orders of magnitudes below the one detected in X0 to set min eps