Skip to contents

Extraction and plotting of connected subnetworks from a graph and a set of selected vertices

Usage

extract_module(
  graph = NULL,
  selectedVertices = NULL,
  NSIRes = NULL,
  column = 1,
  minSubnetSize = 2
)

Arguments

graph

igraph object

selectedVertices

subset of vertices

NSIRes

result of calc_adjND() or calc_dS()

column

which column to consider among those available in the elements of calc_adjND()

minSubnetSize

minimum size of subnetwork

Value

subnetwork