Extraction and plotting of connected subnetworks from a graph and a set of selected vertices
extract_module.RdExtraction and plotting of connected subnetworks from a graph and a set of selected vertices
Usage
extract_module(
graph = NULL,
selectedVertices = NULL,
NSIRes = NULL,
column = 1,
minSubnetSize = 2
)